// -*- C++ -*-
//===----------------------------------------------------------------------===//
//
// Copyright (C) Intel Corporation
//
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
//
// This file incorporates work covered by the following copyright and permission
// notice:
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
//
//===----------------------------------------------------------------------===//

#include "support/test_config.h"
#include "support/test_macros.h"
#include "support/utils.h"

#if _ENABLE_STD_RANGES_TESTING
#include <ranges>
#include "xpu_std_ranges_test.h"
#endif //_ENABLE_STD_RANGES_TESTING

int
main()
{
    bool bProcessed = false;

#if _ENABLE_STD_RANGES_TESTING && !_PSTL_LIBSTDCXX_XPU_DROP_VIEW_BROKEN
    auto test = [](){
        auto res = std::ranges::views::iota(0, 4) | std::ranges::views::drop(2);
        return res.size() == 2 && res[0] == 2 && res[1] == 3 && *res.begin() == 2
               && res.end() - res.begin() == 2;
    };
    const bool res = kernel_test<class std_drop_test>(test);
    EXPECT_TRUE(res, "Wrong result of drop_view check within a kernel");
    bProcessed = true;
#endif //_ENABLE_STD_RANGES_TESTING && !_PSTL_LIBSTDCXX_XPU_DROP_VIEW_BROKEN

    return TestUtils::done(bProcessed);
}
